@@ -15,23 +15,25 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "drawzone.h"
+
 // Qt
-#include <qbitmap.h>
+#include <QBitmap>
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QMimeData>
 #include <QResizeEvent>
-#include <qpainter.h>
-#include <qpixmap.h>
+#include <QPainter>
+#include <QPixmap>
 #include <QMouseEvent>
 #include <QStandardPaths>
-#
+
 // KDE Frameworks
 #include "kimagemapeditor_debug.h"
 
 // Local
-#include "drawzone.h"
 #include "kimagemapeditor.h"
 #include "kimecommands.h"
 #include "areacreator.h"
@@ -856,7 +858,7 @@ void DrawZone::paintEvent(QPaintEvent*) {
 }
 
 void DrawZone::dragEnterEvent(QDragEnterEvent*e) {
-  KUrl::List uris = KUrl::List::fromMimeData( e->mimeData() );
+  QList<QUrl> uris = e->mimeData()->urls();
 
   if ( uris.isEmpty() )
     return;
@@ -870,7 +872,7 @@ void DrawZone::dragEnterEvent(QDragEnterEvent*e) {
 }
 
 void DrawZone::dropEvent( QDropEvent* e) {
-  KUrl::List urlList = KUrl::List::fromMimeData( e->mimeData() );
+  QList<QUrl> urlList = e->mimeData()->urls();
   // A file from konqueror was dropped
 	if (!urlList.isEmpty()) {
 		imageMapEditor->openFile(urlList.first());
